@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkLabelSizeCalculator extends vtkPassInputTypeAlgorithm
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkLabelSizeCalculator extends vtkPassInputTypeAlgorithm
 
     if (temp == 0) return null;
     return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetLabelSizeArrayName_4(String id0);
   public void SetLabelSizeArrayName(String id0)
@@ -35,6 +35,14 @@ public class vtkLabelSizeCalculator extends vtkPassInputTypeAlgorithm
   public String GetLabelSizeArrayName()
     { return GetLabelSizeArrayName_5(); }
 
+  private native void SetDPI_6(int id0);
+  public void SetDPI(int id0)
+    { SetDPI_6(id0); }
+
+  private native int GetDPI_7();
+  public int GetDPI()
+    { return GetDPI_7(); }
+
   public vtkLabelSizeCalculator() { super(); }
 
   public vtkLabelSizeCalculator(long id) { super(id); }
