@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkPointDataToCellData extends vtkDataSetAlgorithm
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -31,6 +31,22 @@ public class vtkPointDataToCellData extends vtkDataSetAlgorithm
   public void PassPointDataOff()
     { PassPointDataOff_5(); }
 
+  private native void SetCategoricalData_6(int id0);
+  public void SetCategoricalData(int id0)
+    { SetCategoricalData_6(id0); }
+
+  private native int GetCategoricalData_7();
+  public int GetCategoricalData()
+    { return GetCategoricalData_7(); }
+
+  private native void CategoricalDataOn_8();
+  public void CategoricalDataOn()
+    { CategoricalDataOn_8(); }
+
+  private native void CategoricalDataOff_9();
+  public void CategoricalDataOff()
+    { CategoricalDataOff_9(); }
+
   public vtkPointDataToCellData() { super(); }
 
   public vtkPointDataToCellData(long id) { super(id); }
